import { HttpException, HttpStatus } from '@nestjs/common';
import { User } from './user.entity';
import { Perfil } from '../perfil/perfil.entity';
import { Repository } from 'typeorm';
import { CreateUserDto } from './dto/create-user.dto';
import { UpdateUserDto } from './dto/update-user.dto';
import { JwtService } from '@nestjs/jwt';
export declare class UsersService {
    private readonly userRepository;
    private perfilRepository;
    private readonly horasValidas;
    private readonly jwtService;
    constructor(userRepository: Repository<User>, perfilRepository: Repository<Perfil>, horasValidas: number, jwtService: JwtService);
    isEmailUnique(correo: string, userId?: number): Promise<boolean>;
    isEmailUniqueUpd(correo: string, userId?: number): Promise<boolean>;
    findByEmail(email: string): Promise<Record<string, any>>;
    getData(page?: number, limit?: number): Promise<HttpException | {
        data: {
            id: number;
            nombre: string;
            apellido: string;
            imagen: string;
            telefono: string;
            correo: string;
            created_at: string;
            updated_at: string;
            perfil: {
                id: number;
                nombre: string;
                created_at: string;
                updated_at: string;
            };
        }[];
        meta: {
            total: number;
            page: number;
            limit: number;
            totalPages: number;
        };
    }>;
    searchData(page: number, limit: number, params: any): Promise<HttpException | {
        data: Record<string, any>;
        meta: {
            total: number;
            page: number;
            limit: number;
            totalPages: number;
        };
    }>;
    getDataById(id: number): Promise<HttpException | {
        id: number;
        nombre: string;
        apellido: string;
        imagen: string;
        telefono: string;
        correo: string;
        perfil_id: number;
        created_at: string;
        updated_at: string;
        perfil: {
            id: number;
            nombre: string;
            created_at: string;
            updated_at: string;
        };
        favoritos: {
            created_at: string;
            updated_at: string;
            inmueble: {
                created_at: string;
                updated_at: string;
                id: number;
                bathroom: number;
                dormitorios: number;
                cocheras: number;
                ambientes: number;
                mascotas: string;
                cuarto_servicio: string;
                balcon: string;
                terraza: string;
                ascensor: string;
                condominio: string;
                deposito: string;
                proyecto: string;
                areas_sociales: string;
                area: number;
                area_techada: number;
                precio: string;
                precio_mantenimiento: string;
                piso: number;
                descripcion: string;
                direccion: string;
                latitud: string;
                longitud: string;
                zoom: string;
                antiguedad: number;
                estreno: string;
                titulo: string;
                tipo_vivienda_id: number;
                tipo_operacion_id: number;
                tipo_inmueble_id: number;
                nivel_amoblado_id: number;
                distrito_id: number;
                user_id: number;
                tipo_ubicacion_id: number;
                estado_inmueble_id: number;
                deleted_at: Date;
                tipo_moneda_id: number;
                estado_id: number;
                tipoMoneda: import("../tipo-moneda/tipo-moneda.entity").TipoMoneda;
                tipoVivienda: import("../tipo-vivienda/tipo-vivienda.entity").TipoVivienda;
                tipoOperacion: import("../tipo-operacion/tipo-operacion.entity").TipoOperacion;
                estado: import("../estado/estado.entity").Estado;
                estadoInmueble: import("../estado-inmueble/estado-inmueble.entity").EstadoInmueble;
                tipoInmueble: import("../tipo-inmueble/tipo-inmueble.entity").TipoInmueble;
                nivelAmoblado: import("../nivel-amoblado/nivel-amoblado.entity").NivelAmoblado;
                distrito: import("../distrito/distrito.entity").Distrito;
                user: User;
                tipoUbicacion: import("../tipo-ubicacion/tipo-ubicacion.entity").TipoUbicacion;
                favoritos: import("../favoritos/favoritos.entity").Favoritos[];
                inmuebleAreasSociales: import("../inmueble-areas-sociales/inmueble-areas-sociales.entity").InmuebleAreasSociales[];
                galeria: import("../galeria/galeria.entity").Galeria[];
                inmuebleEstados: import("../inmueble-estados/inmueble-estados.entity").InmuebleEstados[];
                inmuebleVistas: import("../inmueble-vistas/inmueble-vistas.entity").InmuebleVistas[];
            };
            id: number;
            deleted_at: Date;
            inmueble_id: number;
            user_id: number;
            user: User;
        }[];
    }>;
    createUser(user: CreateUserDto): Promise<{
        data: {
            created_at: string;
            updated_at: string;
            perfil: any;
            id: number;
            correo: string;
            password: string;
            nombre?: string;
            apellido?: string;
            token?: string;
            imagen?: string;
            telefono?: string;
            updated_at_token: Date;
            deleted_at?: Date;
            perfil_id: number;
            inmuebles: import("../inmueble/inmueble.entity").Inmueble[];
            favoritos: import("../favoritos/favoritos.entity").Favoritos[];
            busquedas: import("../busquedas/busquedas.entity").Busquedas[];
        };
        status: HttpStatus;
        message: string;
    }>;
    updateData(id: number, user: UpdateUserDto): Promise<HttpException | {
        data: {
            created_at: string;
            updated_at: string;
            perfil: {
                created_at: string;
                updated_at: string;
                id: number;
                nombre: string;
                deleted_at: Date;
                user: User[];
            };
            id: number;
            correo: string;
            password: string;
            nombre?: string;
            apellido?: string;
            token?: string;
            imagen?: string;
            telefono?: string;
            updated_at_token: Date;
            deleted_at?: Date;
            perfil_id: number;
            inmuebles: import("../inmueble/inmueble.entity").Inmueble[];
            favoritos: import("../favoritos/favoritos.entity").Favoritos[];
            busquedas: import("../busquedas/busquedas.entity").Busquedas[];
            password_confirm?: string;
        };
        status: HttpStatus;
        message: string;
    }>;
    updatePass(id: number, user: UpdateUserDto): Promise<HttpException | {
        data: {
            created_at: string;
            updated_at: string;
            id: number;
            correo: string;
            password: string;
            nombre?: string;
            apellido?: string;
            token?: string;
            imagen?: string;
            telefono?: string;
            updated_at_token: Date;
            deleted_at?: Date;
            perfil_id: number;
            perfil: Perfil;
            inmuebles: import("../inmueble/inmueble.entity").Inmueble[];
            favoritos: import("../favoritos/favoritos.entity").Favoritos[];
            busquedas: import("../busquedas/busquedas.entity").Busquedas[];
            password_confirm?: string;
        };
        status: HttpStatus;
        message: string;
    }>;
    deleteData(id: number): Promise<HttpException | import("typeorm").UpdateResult>;
    loginUser(inputCorreo: string, inputPassword: string): Promise<HttpException | {
        userFound: Record<string, any>;
        status: HttpStatus;
        message: string;
    }>;
    validaUserActive(id: number, token: string): Promise<HttpException | {
        userFound: User;
        status: HttpStatus;
        horasTranscurridas: number;
        horasValidas: number;
        message: string;
    }>;
}
